@@ -43,6 +43,7 @@ class BaseAPI:
     def __init__(self, server, email, password):
         self.server = server
         self.token = None
+        self._public_url = ''
         self._login(email, password)
 
     def _login(self, email, password):
@@ -64,6 +65,13 @@ class BaseAPI:
             raise Exception('Not authenticated')
         return {'Authorization': 'Token {}'.format(self.token)}
 
+    def set_public_url(self, public_url: str):
+        self._public_url = public_url
+
+    def public_url(self, endpoint, *args, **kwargs):
+        url = self._public_url if self._public_url else self.server
+        return self._build_url(url, endpoint, *args, **kwargs)
+
     def url(self, endpoint, *args, **kwargs):
         return self._build_url(self.server, endpoint, *args, **kwargs)
 
@@ -358,7 +366,7 @@ class API(BaseAPI):
         return self.get(url).json()
 
     def export_annotations(
-        self, annotation_set_id: int, annotation_format='json', export_coordinates='pixel', full_path='true'
+        self, annotation_set_id: int, annotation_format='json', export_coordinates='pixel', full_path=True, export_tags: bool = True,
     ) -> bytes:
         """
         Exports annotations in given format
@@ -366,9 +374,9 @@ class API(BaseAPI):
         Args:
             annotation_set_id: annotation set id
             annotation_format: can be one of ['json', 'coco', 'csv'], default='json'
-            full_path: uses full image path (e.g. local path), can be one of ['true', 'false'], default='false'
+            full_path: uses full image path (e.g. local path),  it can be one of [True, False], default=True
             export_coordinates: converts output values to percentage or pixels, can be one of ['pixel', 'percent'], default='pixel'
-
+            export_tags: exports the tags to a CSV file, it can be one of [True, False], default=True
         Returns:
             annotation file content
         """
@@ -376,7 +384,8 @@ class API(BaseAPI):
             backend.v1_export_annotations.format(annotation_set_id),
             annotation_format=annotation_format,
             export_coordinates=export_coordinates,
-            full_path=full_path,
+            full_path=str(full_path).lower(),
+            export_tags=str(export_tags).lower()
         )
         return self.get(url).content
 
